'use strict';

var express = require('express');
var mesaController = require('../Controllers/mesaController');
var userController = require('../Controllers/userController');
var menuController = require('../Controllers/menuController');
var cuentaController = require('../Controllers/cuentaController');
var facturaController = require('../Controllers/facturaController');
var opcionesController = require('../Controllers/opcionesController');
var preCuentaController =  require('../Controllers/preCuentaController');
var ticketController = require('../Controllers/ticketController');
var registroVentasController = require('../Controllers/registroVentasController');
var printerController = require('../Controllers/printerController');
var tiposDecobroController = require('../Controllers/config')

const auth = require('../auth/get_auth')


var api = express.Router();
//------------------------Rutas mesa--------------------//
api.post('/crearMesa', mesaController.guardarMesa);
api.put('/actualizarMesa/:id', mesaController.actualizarMesa);
api.put('/eliminarMesa/:id', mesaController.eliminarMesa);
api.get('/listarMesa', mesaController.listarMesa);
api.get('/buscarMesa/:id', mesaController.buscarMesa);
api.get('/buscarMesaTipo/:tipo',auth, mesaController.buscarMesaTipo);
api.post('/buscarMesaBy/:num/:tipo', mesaController.buscarMesaBy);
api.get('/areasmesas',auth, mesaController.getAreasMesas);

//------------------------Rutas usuario--------------------//
api.post('/crearUsuario', userController.crearUsuario);
api.post('/credentials', userController.credentials);
api.put('/actualizarUsuario/:id', userController.actualizarUsuario);
api.put('/eliminarUsuario/:id', userController.eliminarUsuario);
api.get('/listarUsuarios', userController.listarUsuarios);
api.get('/buscarUsuario/:id', userController.buscarUsuario);
api.get('/login/:id/:username/:pin', userController.login);
api.get('/logout',auth, userController.logout)



//------------------------Rutas menu--------------------//
api.post('/crearPlato', menuController.crearPlato);
api.put('/actualizarPlatillo/:id', menuController.actualizarPlatillo);
api.put('/eliminarPlatillo/:id', menuController.eliminarPlatillo);
api.get('/listarPlatillos', menuController.listarPlatillos);
api.get('/listarPlatillosmenu/:num/:tipo',auth, menuController.listarMenuPlatillos);
api.get('/buscarPlatillo/:id', menuController.buscarPlatillo);
api.get('/buscarPorTipo/:idnivel1/:idnivel2', auth,menuController.buscarPorTipo);
//------------------------Rutas cuenta--------------------//
api.post('/crearCuenta',auth, cuentaController.crearCuenta);
api.put('/actualizarCuenta',auth, cuentaController.actualizarCuenta);
api.put('/eliminarproducto',auth, cuentaController.removeItemfromCuenta);
api.put('/printitem',auth, cuentaController.printItem);
api.put('/anularproducto',auth, cuentaController.anularItemfromCuenta);
api.put('/eliminarCuenta/:id', auth,cuentaController.eliminarCuenta);
api.put('/clearcuenta/:id', auth,cuentaController.clearCuenta);
api.get('/listarCuentas', cuentaController.listarCuentas);
api.get('/listarCuentasActivas', cuentaController.listarCuentasActivas);
api.get('/buscarCuenta/:id', cuentaController.buscarCuenta);
api.put('/actualizarImpresado/:id', cuentaController.actualizarImpresado);
api.post('/printComanda', auth,cuentaController.printComanda);
//------------------------Rutas factura--------------------//
api.post('/crearFactura',auth, facturaController.guardarFactura);
api.post('/anularfactura',auth, facturaController.anularFacturaController);
api.put('/actualizarFactura/:id', facturaController.actualizarFactura);
api.put('/eliminarFactura/:id', facturaController.eliminarFactura);
api.get('/listarFacturas', facturaController.listarFacturas);
api.get('/buscarFactura/:id', facturaController.buscarFactura);
api.get('/apivalidatenit/:nit',auth,facturaController.validateNit);
api.post('/printresumencierre',facturaController.printresumencierre);
 
api.get('/buscarPorFecha/:fechaEncontrar',auth, facturaController.buscarPorFecha);
api.post('/generarcierre/:fechaEncontrar',auth, facturaController.generarCierrredeCaja);
api.get('/getfondoCaja/:fechaEncontrar',auth, facturaController.getFondoCaja);
api.get('/gettasadeCambio',auth, facturaController.getTasaDeCambio);
api.post('/setfondocaja',auth, facturaController.setFondoCaja)
api.post('/re-imprimir-factura/:idventa',auth, facturaController.re_imprimirFactura_recibo)

//-----------------------Rutas opciones-----------------------//
api.post('/crearPreCuenta',auth, preCuentaController.guardarPreCuenta);
//-----------------------Rutas opciones-----------------------//
api.get('/listarOpciones/:idplatillo', auth,opcionesController.listarOpciones);
//-----------------------Rutas Tickets------------------------//
api.post('/printTickets', ticketController.printTickets);

//-------------------- Rutas Ventas Detalles----------------//

api.get('/get-registro-ventas/:fechaEncontrar', auth,registroVentasController.getVentasDetalles);


//___-------------RUTAS DE CONFIGURACION///////////////


api.get('/tipodecobros', auth,tiposDecobroController.getTiposDeCobro);
api.put('/enable_disable_tipodeCobro/:id/:value', auth,tiposDecobroController.changeButtonState);

module.exports = api;